/**
 * @file task_user.h
 * @brief The FreeRTOS task to run the user interface.
 */

#ifndef	_TASK_USER_H
#define	_TASK_USER_H


#define PIN_SDA                 (CONFIG_I2C_MASTER_SDA)
#define PIN_SCL                 (CONFIG_I2C_MASTER_SCL)
#define ROT_ENC_A_GPIO          (CONFIG_ROT_ENC_A_GPIO)
#define ROT_ENC_B_GPIO          (CONFIG_ROT_ENC_B_GPIO)
#define ROT_ENC_SW_GPIO         (CONFIG_ROT_ENC_SW_GPIO)
#define INACTIVITY              120                                     ///< User inactivity time

#define EDIT_TYPE_TEXT          0                                       ///< Editor type is text, special chars and digits.
#define	EDIT_TYPE_CAPS		1					///< Editor alpha capitals, some specials and digits.
#define EDIT_TYPE_INT           2                                       ///< Editor type is integer
#define EDIT_TYPE_FLOAT         3                                       ///< Editor type is float



/**
 * @brief Called after a power on or hard reset.
 */
void user_cold(void);


/**
 * @brief Called after wakeup by the user.
 */
void user_wakeup(void);


/**
 * @brief Refresh screens that are in focus.
 */
void user_refresh(void);


/**
 * @brief Test is user interface is busy and active
 * @return Returns true if the user interface is active, false otherwise.
 */
bool user_busy(void);


/**
 * @brief The FreeRTOS task to run the user interface.
 */
void task_user(void *);


#endif

